@@ -22,7 +22,7 @@ static void help()
        "Example of <video_name> is in opencv_extra/testdata/cv/tracking/\n"
        "Call:\n"
        "./tracker <tracker_algorithm> <video_name> <start_frame> [<bounding_frame>]\n"
-       "tracker_algorithm can be: MIL, BOOSTING, MEDIANFLOW, TLD\n"
+       "tracker_algorithm can be: MIL, BOOSTING, MEDIANFLOW, TLD, KCF, GOTURN, MOSSE.\n"
        << endl;
 
   cout << "\n\nHot keys: \n"
@@ -93,7 +93,7 @@ int main( int argc, char** argv ){
 
   //instantiates the specific Tracker
   Ptr<Tracker> tracker = createTrackerByName(tracker_algorithm);
-  if( tracker == NULL )
+  if (!tracker)
   {
     cout << "***Error in the instantiation of the tracker...***\n";
     return -1;
@@ -117,6 +117,7 @@ int main( int argc, char** argv ){
 
   bool initialized = false;
   int frameCounter = 0;
+  int64 timeTotal = 0;
 
   for ( ;; )
   {
@@ -142,11 +143,14 @@ int main( int argc, char** argv ){
       }
       else if( initialized )
       {
+        int64 frameTime = getTickCount();
         //updates the tracker
         if( tracker->update( frame, boundingBox ) )
         {
           rectangle( image, boundingBox, Scalar( 255, 0, 0 ), 2, 1 );
         }
+        frameTime = getTickCount() - frameTime;
+        timeTotal += frameTime;
       }
       imshow( "Tracking API", image );
       frameCounter++;
@@ -159,5 +163,8 @@ int main( int argc, char** argv ){
       paused = !paused;
   }
 
+  double s = frameCounter / (timeTotal / getTickFrequency());
+  printf("FPS: %f\n", s);
+
   return 0;
 }
